import getData from '../actions/getData.js';
import loadJson from '../utils/loadJson.js';

export default function exportReactNative(platform, bridgePath = null) {
    const env = JSON.stringify(getData('env', platform));

    const bridgeExportFile = `${bridgePath}.exports.json`;
    let symbols = null;
    if (bridgePath) {
        symbols = loadJson(bridgeExportFile);
    }

    let symbolExportDefineString = '';
    let symbolExportAssignString = '';
    if (symbols && Array.isArray(symbols)) {
        symbolExportDefineString = symbols.map((s) => `export let ${s} = null;`).join('\n');
        symbolExportAssignString = symbols.map((s) => `${s} = Module.${s};`).join('\n');
    }

    return `
import { NativeModules } from 'react-native';
import Module from '@cpp.js/core-embind-jsi';

const { RNJsiLib } = NativeModules;

function setEnv() {
    const env = JSON.parse('${env}');
    const CPPJS_DATA_PATH = Module.CppJS.getEnv('CPPJS_DATA_PATH');

    Object.entries(env).forEach(([key, value]) => {
        Module.CppJS.setEnv(key, value.replace('_CPPJS_DATA_PATH_', CPPJS_DATA_PATH), true);
    });
}

export let AllSymbols = {};
${symbolExportDefineString}
export function initCppJs(config = {}) {
    return new Promise((resolve, reject) => {
        if (RNJsiLib && RNJsiLib.start) {
            RNJsiLib.start();
            setEnv();
            AllSymbols = Module;
            ${symbolExportAssignString}
            resolve(Module);
        } else {
            reject('Module failed to initialise.');
        }
    });
}
`;
}
